#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 semirings
version:              0.7
visibility:           public
id:                   semirings-0.7-HtwNMgVyKGXJutn1xgYyaT
key:                  semirings-0.7-HtwNMgVyKGXJutn1xgYyaT
license:              BSD-3-Clause
copyright:            Copyright (C) 2018 chessai
maintainer:           chessai <chessai1996@gmail.com>
author:               chessai
stability:            provisional
homepage:             http://github.com/chessai/semirings
synopsis:             two monoids as one, in holy haskimony
description:
    Haskellers are usually familiar with monoids and semigroups. A monoid has an appending operation `<>` (or `mappend`),
    and an identity element, `mempty`. A semigroup has an appending `<>` operation, but does not require a `mempty` element.

    A Semiring has two appending operations, `plus` and `times`, and two respective identity elements, `zero` and `one`.

    More formally, a Semiring R is a set equipped with two binary relations `+` and `*`, such that:

    (R,+) is a commutative monoid with identity element 0,

    (R,*) is a monoid with identity element 1,

    (*) left and right distributes over addition, and

    multiplication by '\''0'\'' annihilates R.

category:             Algebra, Data, Data Structures, Math, Maths, Mathematics
abi:                  6a8437e0802d50b4390e1049ce76a885
exposed:              True
exposed-modules:
    Data.Euclidean Data.Field Data.Ring.Ordered Data.Semiring
    Data.Semiring.Directed Data.Semiring.Generic Data.Semiring.Tropical
    Data.Star

import-dirs:          /usr/lib/ghc-9.6.6/site-local/semirings-0.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/semirings-0.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/semirings-0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semirings
hs-libraries:         HSsemirings-0.7-HtwNMgVyKGXJutn1xgYyaT
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-ISMWzeTPqg7GxJZ08wJoa
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1

haddock-interfaces:   /usr/share/doc/haskell-semirings/html/semirings.haddock
haddock-html:         /usr/share/doc/haskell-semirings/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

